@@ -1,6 +1,13 @@
 #ifndef __HIREDIS_EXT_H
 #define __HIREDIS_EXT_H
 
+/* Defined for Rubinius. This indicates a char* obtained
+ * through RSTRING_PTR is never modified in place. With this
+ * define Rubinius can disable the slow copy back mechanisms
+ * to make sure strings are updated at the Ruby side.
+ */
+#define RSTRING_NOT_MODIFIED
+
 #include "hiredis.h"
 #include "ruby.h"
 
