@@ -82,7 +82,7 @@ module ConnectionTests
     ex = assert_raises RuntimeError do
       hiredis.connect("nonexisting", 6379)
     end
-    assert ex.message =~ /(can't resolve)|(name or service not known)/i
+    assert ex.message =~ /(can't resolve)|(name or service not known)|(nodename nor servname provided, or not known)/i
   end
 
   def test_connect_wrong_port
